@@ -1,8 +1,8 @@
 """
-ImageNode - a Python Class to govern the data and metadata of image data (OpenCV, PIL). \n
+ImageNode is a Python Class to govern the data and metadata of image data (OpenCV, PIL). 
 
-This node builds upon the OpenCV and PIL API for the image definitions.\n
-It directly inherits from Node.\n
+This node builds upon the OpenCV and PIL API for the image definitions.
+It directly inherits from Node.
 Be sure to check the properties defined in the above classes to initialise the Node.
 """
 #IMPORT PACKAGES
@@ -38,26 +38,20 @@ class ImageNode(Node):
                         getResource : bool = False,
                         getMetaData : bool = True,
                         **kwargs): 
-        """
-        Creates a ImageNode. Overloaded function.\n
-        This Node can be initialised from one or more of the inputs below.\n
-        By default, no data is imported in the Node to speed up processing.\n
+        """Creates a Node from one or more of the following inputs. 
+        By default, no data is imported in the Node to speed up processing.
         If you also want the data, call node.get_resource() or set getResource() to True.\n
 
         Args: \n
-            0.graph (RDFlib Graph) : Graph with a single subject (if multiple subjects are present, only the first will be used to initialise the MeshNode)\n
-            
-            1.graphPath (str):  Graph file path with a single subject (if multiple subjects are present, only the first will be used to initialise the MeshNode)\n
-
-            2.path (str) : path to image file (Note that this node will also contain the data) \n
-
-            3.resource (ndarray, PIL Image,Open3D) : OpenCV, PIL (Note that this node will also contain the data)\n
-
-            4.xmlPath (str) : Xml file path from Agisoft Metashape\n
-
-            5.xmpPath (str) :  xmp file path from RealityCapture
-
-            getResource (bool, optional= False): If True, the node will search for its physical resource on drive \n
+            1. graph (RDFlib Graph) : Graph with a single subject (if multiple subjects are present, only the first will be used to initialise the MeshNode)\n
+            2. graphPath (str):  Graph file path with a single subject (if multiple subjects are present, only the first will be used to initialise the MeshNode)\n
+            3. path (str) : path to image file (Note that this node will also contain the data) \n
+            4. resource (ndarray, PIL Image,Open3D) : OpenCV, PIL (Note that this node will also contain the data)\n
+            5. xmlPath (str) : Xml file path from Agisoft Metashape\n
+            6. xmpPath (str) :  xmp file path from RealityCapture
+            \n
+            - getResource (bool, optional= False): If True, the node will search for its physical resource on drive \n
+            - getMetaData (bool, optional= True): If True, the node will attempt to extract metadata from the resource if present \n
 
         Returns:
             An ImageNode with metadata 
@@ -132,8 +126,8 @@ class ImageNode(Node):
         """Get the orientedBoundingBox of the Node from various inputs. \n
 
         Args:
-            1.Open3D.geometry.OrientedBoundingBox \n
-            2.Open3D geometry\n
+            1. Open3D.geometry.OrientedBoundingBox \n
+            2. Open3D geometry\n
 
         Returns:
             orientedBoundingBox (o3d.geometry.OrientedBoundingBox) 
@@ -174,8 +168,13 @@ class ImageNode(Node):
             raise ValueError('Resource must be np.ndarray (OpenCV) or PIL Image')
 
     def get_resource(self)->np.ndarray: 
-        """Returns the resource (image) in the node. \n
-        If none is present, it will search for the data on drive from path, graphPath, name or subject. \n
+        """Returns the resource (image) in the node. 
+        If none is present, it will search for the data on drive from the following inputs. \n
+
+        Args:
+            1. self.path\n
+            2. self.graphPath\n
+            3. self.name or self.subject
 
         Returns:
             np.ndarray or None
@@ -187,12 +186,13 @@ class ImageNode(Node):
         return self._resource  
 
     def get_path(self) -> str:
-        """Returns the full path of the resource from various inputs.\n
+        """Returns the full path of the resource.
+        If none is present, it will search for the data on drive from the following inputs.\n
 
         Args:
-            1. self._graphPath \n
-            2. self._name \n
-            3. self._subject\n
+            1. self.graphPath \n
+            2. self.name \n
+            3. self.subject\n
 
         Returns:
             resource path (str)
@@ -236,8 +236,13 @@ class ImageNode(Node):
             return None
 
     def get_xmp_path(self)->str: 
-        """Returns the xmpPath in the node. \n
-        If none is present, it will search for the data on drive from path, graphPath, name or subject. \n
+        """Returns the xmpPath in the node. 
+        If none is present, it will search for the data on drive from the following inputs.\n
+
+        Args:
+            1. self.graphPath \n
+            2. self.name \n
+            3. self.subject\n
 
         Returns:
             str or None
@@ -324,8 +329,8 @@ class ImageNode(Node):
         """Returns the metadata from a resource. \n
 
         Features:
-            imageHeight\n
-            imageWidth\n
+            1. imageHeight\n
+            2. imageWidth\n
 
         Returns:
             bool: True if exif data is successfully parsed
@@ -387,14 +392,17 @@ class ImageNode(Node):
             return None
 
     def get_virtual_image(self, geometries: o3d.geometry, downsampling:int=2)-> o3d.cpu.pybind.geometry.Image:
-        """_summary_
+        """Generates a virtual image of a set of geometries given the ImageNode's pose and piholeModel.
+
+        .. image:: ../../../docs/pics/rendering3.PNG
+
 
         Args:
-            geometries (o3d.geometry): _description_
-            downsampling (int, optional): _description_. Defaults to 2.
+            1. geometries (o3d.geometry): geometries to include in the scene of the virtual image.\n
+            2. downsampling (int, optional): pixel downsampling of the image both in height and width (each step reduces the density by factor 4). Defaults to 2.
 
         Returns:
-            o3d.cpu.pybind.geometry.Image: _description_
+            o3d.cpu.pybind.geometry.Image or None
         """
         pinholeCamera=self.get_pinhole_camera_parameters(downsampling)
         if pinholeCamera is not None:
@@ -403,6 +411,20 @@ class ImageNode(Node):
             return None
 
     def get_pinhole_camera_parameters(self, downsampling:int=2) -> o3d.camera.PinholeCameraParameters():
+        """Returns the intrinsic and extrinsix camera parameters based on the following attributes.
+
+        .. image:: ../../../docs/pics/pinholemodel1.PNG
+
+        Args:
+            1. self.imageWidth: width of the image in pixels (u) \n
+            2. self.imageHeight: height of the image in pixels (v) \n
+            3. self.focalLength35mm: focal length with a standardised Field-of-View.\n 
+            4. self.cartesianTransform: the inverted transform equals the external camera pose.\n
+            2. downsampling (int, optional): pixel downsampling of the image both in height and width (each step reduces the density by factor 4). Defaults to 2.
+
+        Returns:
+            o3d.camera.PinholeCameraParameters()
+        """
         param=o3d.camera.PinholeCameraParameters()
         if getattr(self,'cartesianTransform',None) is not None:
             param.extrinsic=np.linalg.inv(self.cartesianTransform)
@@ -413,7 +435,18 @@ class ImageNode(Node):
             return None
 
     def get_intrinsic_camera_parameters(self, downsampling:int=2) -> o3d.camera.PinholeCameraIntrinsic():
+        """Returns the intrinsic camera parameters based on the following attributes.
+        
+        Args:
+            1. self.imageWidth: width of the image in pixels (u). Defaults to 640p \n
+            2. self.imageHeight: height of the image in pixels (v). Defaults to 480p  \n
+            3. self.focalLength35mm: focal length with a standardised Field-of-View. Defaults to 25mm \n 
+            4. self.PrincipalPointU: cx \n
+            4. self.PrincipalPointV: cy \n
 
+        Returns:
+            o3d.camera.PinholeCameraIntrinsic(width,height,fx,fy,cx,cy)
+        """
         width=640
         height=480
         f=25
@@ -443,13 +476,14 @@ class ImageNode(Node):
         """Returns the metadata from a resource. \n
 
         Features:
-            GPSInfo (geospatialTransform (np.array(3,1)),coordinateSystem (str)) \n
-            DateTime\n
-            XResolution\n
-            YResolution\n
-            ResolutionUnit \n
-            ExifImageWidth \n
-            ExifImageHeight \n
+            1. GPSInfo (geospatialTransform (np.array(3,1))
+            2. coordinateSystem (str) \n
+            2. DateTime ('%Y-%m-%dT%H:%M:%S')\n
+            3. XResolution (int)\n
+            4. YResolution (int)\n
+            5. ResolutionUnit (int)\n
+            6. ExifImageWidth (int)\n
+            7. ExifImageHeight (int)\n
 
         Returns:
             bool: True if meta data is successfully parsed
@@ -498,15 +532,15 @@ class ImageNode(Node):
             return False
     
     def get_metadata_from_xmp_path(self)->bool:
-        """Read Metadata from .xmp file generated by https://www.capturingreality.com/
+        """Read Metadata from .xmp file generated by https://www.capturingreality.com/.
 
         Features:
-            geospatialTransform\n
-            coordinateSystem\n
-            focalLength35mm\n
-            principalPointU\n
-            principalPointV \n
-            cartesianTransform \n
+            1. geospatialTransform (np.array(3x1))\n
+            2. coordinateSystem (str)\n
+            3. focalLength35mm (float)\n
+            4. principalPointU (float)\n
+            5. principalPointV (float)\n
+            6. cartesianTransform (np.array(4x4))\n
 
         Returns:
             bool: True if metadata is sucesfully parsed
@@ -568,9 +602,9 @@ class ImageNode(Node):
         """Extract image metadata from XML Node generated by Agisoft Metashape (self.xmlData and self.subject should be present).
 
         Features:
-            cartesianTransform\n
-            sxy\n
-            sz \n
+            1. cartesianTransform (np.array(4x4))\n
+            2. sxy: accuracy in XY (m)\n
+            3. sz: accuracy in Z (m) \n
 
         Returns:
             bool: True if metadata is sucesfully parsed
@@ -621,12 +655,14 @@ class ImageNode(Node):
             raise ValueError ('subject not in xml file') 
 
     def set_cartesianTransform(self,value):
-        """validate cartesianTransform valid inputs are:
-        0.cartesianTransform(np.ndarray(4x4))
-        1.p.ndarray or Vector3dVector (1x3)  
-        2.cartesianBounds (np.ndarray (6x1))
-        3.np.ndarray or Vector3dVector (8x3 or nx3)
-        4.Open3D.geometry
+        """Set the cartesianTransform of the ImageNode from various inputs.
+        
+        Args:
+            1. cartesianTransform(np.ndarray(4x4))\n
+            2. np.ndarray or Vector3dVector (1x3)  \n
+            3. cartesianBounds (np.ndarray (6x1))\n
+            4. np.ndarray or Vector3dVector (8x3 or nx3)\n
+            5. Open3D.geometry
         """        
         try: #np.ndarray (4x4) 
             self._cartesianTransform=np.reshape(value,(4,4))
@@ -648,8 +684,13 @@ class ImageNode(Node):
 
 
     def get_cartesian_transform(self) -> np.ndarray:
-        """Get the cartesianTransform (translation & rotation matrix) (np.ndarray(4x4)) of the node from the 
-        cartesianBounds, orientedBounds, orientedBoundingBox an Open3D geometry or a list of Vector3dVector objects.
+        """Get the cartesianTransform from various inputs.
+        
+        Args:
+            1. self.cartesianBounds (np.array(6x1))  \n
+            2. self.orientedBounds (np.array(8x3)) or a list of Vector3dVector objects  \n
+            3. orientedBoundingBox\n
+            4. Open3D.geometry
 
         Returns:
             cartesianTransform(np.ndarray(4x4))
