@@ -1,9 +1,10 @@
 """
-Node - an abstract Python Class to govern the data and metadata of remote sensing data (pcd, images, meshes, orthomozaik) \n
-
-This is the base class for all other node classes. \n
-It contains the base RDF graph functionality and i/o from and to RDF files. \n
+**Node** is an abstract Python Class to govern the data and metadata of remote sensing data (pcd, images, meshes, orthomozaik).
+It is the base class for all other node classes. It contains the base RDF graph functionality and i/o from and to RDF files. \n
    
+**IMPORTANT**: the Node class is an archytype class from which specific data classes (e.g. PointCloudNode) inherit.
+Do not use this class directly if you can use a child class with more functionality.
+
 Goals:\n
 - Govern the metadata and geospatial information of big data files in an accesible and lightweight format. \n
 - Serialize the metadata of remote sensing and geospatial files (BIM, Point clouds, meshes, etc.) as RDF Graphs  \n
@@ -38,18 +39,15 @@ class Node:
                         resource=None,
                         cartesianTransform:np.ndarray=None,
                         **kwargs):
-        """Creates a Node. Overloaded function. \n
-        This Node can be initialised from one or more of the inputs below.
-
-        <ins>IMPORTANT</ins>: the Node class is an archytype class from which specific data classes (e.g. PointCloudNode) inherit.
-        Do not use this class directly if you can use a child class with more functionality.
+        """Creates a Node from one or more of the following inputs. \n
 
         Args:
-            0.graph (Graph, optional): The RDF Graph to parse. Defaults to None. \n
-            1.graphPath (str, optional): The path of the Graph. If no subject is provided, the first subject of the graph is withheld. Defaults to None.\n
-            2.path(str,optional): The path of the resource. Defaults to None.\n
-            3.subject (URIRef, optional): The subject of the Node. If a graph is also present, the subject should be part of the graph. Defaults to None.\n
-            4.name (str, optional): Name of the subject.\n
+            1.graph (Graph, optional): An RDF Graph to parse.\n
+            2.graphPath (str, optional): The path of an RDF Graph to parse. If no subject is provided, the first subject of the graph is retained. \n
+            3.path(str,optional): A filepath to a resource. \n
+            4.subject (URIRef, optional): A subject to use as identifier for the Node. If a graph is also present, the subject should be part of the graph.\n
+            5.name (str, optional): A name of the Node. This is not a unique identifier but serves as non-functional description.\n
+
         Returns:
             Node
         """
@@ -98,9 +96,13 @@ class Node:
     #---------------------PATH----------------------------
     @property
     def path(self): 
-        """Get the resource path (str) of the node. \n
-        If no path is present, a path is reconstructed from either 
-        the graphPath or working directory (folder,self.name,nodeExtensions[0]).
+        """Get the resource path (str) of the node. If no path is present, you can use get_path() to reconstruct the path from either 
+        the graphPath or working directory
+        
+        Features:
+            1. folder\n
+            2. self.name\n
+            3. self.graphPath\n
         """        
         return self._path
     
@@ -117,10 +119,13 @@ class Node:
     #---------------------NAME----------------------------
     @property
     def name(self):
-        """Get the name (str) of the node. \n
-        This can include characters that the operating
-        system does not allow. If no name is provided, 
-        it is gathered from the path or graph upon initialisation."""        
+        """Get the name (str) of the node. This can include characters that the operating
+        system does not allow. If no name is present, you can use get_name() to construct a name from the subject or path.
+
+        Features:
+            1. self.path\n
+            2. self.subject\n
+        """        
         return self._name
 
     @name.setter
@@ -135,8 +140,12 @@ class Node:
     #---------------------TIMESTAMP----------------------------
     @property
     def timestamp(self):
-        """Get the timestamp (yyyy-MM-ddTHH:mm:ss) of the node. \n
-        If no timestamp is provided, it is gathered from the path or graphPath."""
+        """Get the timestamp (str(yyyy-MM-ddTHH:mm:ss)) of the node. If no timestamp is present, use get_timestamp() to gather the timestamp from the path or graphPath.
+
+        Features:
+            1. self.path\n
+            2. self.graphPath\n
+        """
         return self._timestamp
 
     @timestamp.setter
@@ -151,7 +160,7 @@ class Node:
     #---------------------GRAPHPATH----------------------------    
     @property
     def graphPath(self):
-        """Get the path (str) of graph of the node, or the graph in which the subject is contained."""
+        """Get the path (str) of graph of the node, or the graphPath in which the subject is contained."""
         return self._graphPath
 
     @graphPath.setter
@@ -167,8 +176,12 @@ class Node:
     #---------------------GRAPH----------------------------    
     @property
     def graph(self):
-        """Get the graph (RDFLib.Graph) of the node."""       
-        # self._graph =self.to_graph()      # this is expensive!       
+        """Get the graph (RDFLib.Graph) of the node. If no graph is present, you can use get_graph() to parse the graph from a graphPath. Alternatively,
+        you can use to_graph() to serialize the Nodes attributes to RDF.
+        
+        Features:
+            1. self.graphPath
+        """       
         return self._graph
 
     @graph.setter
@@ -183,9 +196,14 @@ class Node:
     #---------------------SUBJECT----------------------------    
     @property
     def subject(self):
-        """Get the subject (RDFLib.URIRef) of the node. \n
-        If no subject is present, it is gathered 
-        from the graph, name, or path. Otherwise, a random guid is generated."""
+        """Get the subject (RDFLib.URIRef) of the node. If no subject is present, you can use get_subject() to construct it from a graph, name or path.
+        Otherwise, a random guid is generated.
+        
+        Features:
+            1. self.name\n
+            2. self.graph\n
+            3. self.path\n
+        """
         return self._subject
 
     @subject.setter
@@ -208,9 +226,13 @@ class Node:
     #---------------------RESOURCE----------------------------    
     @property
     def resource(self):
-        """Get the resource (mesh, pcd, etc.) of the node. \n
-        If no resource is present, it is gathered from the path. 
-        This is the parent could which is specified at every child node."""        
+        """Get the resource (mesh, pcd, etc.) of the node. If no resource is present, you can use get_resource() to load the resource from a path or search it through the name and graphpath. 
+
+        Features:
+            1. self.path\n
+            2. self.name\n
+            3. self.graphPath\n
+        """        
         return self._resource
 
     @resource.setter
@@ -236,10 +258,19 @@ class Node:
     #---------------------CARTESIANTRANSFORM----------------------------    
     @property
     def cartesianTransform(self):
-        """Get the Cartesian Transform (translation & rotation matrix) (np.ndarray(4x4)) of the node.\n
+        """Get the Cartesian Transform (translation & rotation matrix) (np.ndarray(4x4)) of the node.
         Note that the initialisation from different inputs may result in different cartesianTransform values.\n
         E.g. the pose of a mesh is retrieved from the mean of the vertices,
-             while the same pose initiated from the cartesianBounds equals the mean of that cartesianBounds array."""      
+             while the same pose initiated from the cartesianBounds equals the mean of that cartesianBounds array.
+        \n
+        If no cartesianTransform is present, you can use get_cartesianTransform() to construct the cartesiantransform from the resource, cartesianBounds, orientedBounds or orientedBoundingBox.     
+        
+        Features:
+            1. self.cartesianBounds\n
+            2. self.resource\n
+            3. self.orientedBounds\n
+            4. self.orientedBoundingBox\n
+        """      
         return self._cartesianTransform
 
     @cartesianTransform.setter
@@ -251,13 +282,14 @@ class Node:
 
 #---------------------METHODS----------------------------     
     def get_metadata_from_graph(self, graph:Graph,subject:URIRef):
-        """Convert the data contained in a graph to a set of node attributes. \n 
+        """Convert the data contained in a graph to a set of node attributes.
         If the graph contains multiple subjects, it is reduced to the subject's triples. \n
-        The use of a SessionNode is advised when dealing with multi-subject graphs.\n
+        
+        **NOTE**: The use of a SessionNode is advised when dealing with multi-subject graphs.\n
 
         Args:
-            self.graph (RDFlib.Graph):  Graph to parse\n
-            self.subject (RDFlib.URIRef): The subject to parse the graph for
+            1. self.graph (RDFlib.Graph):  Graph to parse\n
+            2. self.subject (RDFlib.URIRef): The subject to parse the graph for
         
         """
         if len([x for x in self._graph.subjects(RDF.type)])>1:
@@ -308,8 +340,7 @@ class Node:
                 setattr(self,attr,object.toPython()) 
 
     def get_subject(self) -> str:
-        """Returns and validates the current subject. \n
-        If empty, a new subject is created based on a unique GUID. \n
+        """Returns and validates the current subject. If empty, a new subject is created based on an unique GUID.\n
 
         Returns:
             subject (URIREF)
@@ -333,7 +364,7 @@ class Node:
         return self._subject
 
     def get_timestamp(self):
-        """Get the timestamp (str) of the Node.\n
+        """Get the timestamp (str) of the Node. 
         This can be retrieved from user input, the path, the graphPath or the current time.\n
 
         Returns:
@@ -362,27 +393,27 @@ class Node:
         return self.name
 
     def set_cartesianTransform(self,value):
-        """sets the cartesianTransform for the Node type. Overwrite this function for each node type
+        """sets the cartesianTransform for the Node type. Overwrite this function for each node type.
         """
         # print("This is the base Node functionality, overwite for each childNode to retrieve the relevant cartesianTransform")
 
     def get_cartesianTransform(self):
-        """Returns the cartesianTransform from the Node type. Overwrite this function for each node type"""
+        """Returns the cartesianTransform from the Node type. Overwrite this function for each node type."""
         # print("This is the base Node functionality, overwite for each childNode to retrieve the relevant cartesianTransform")
 
     def get_resource(self):
-        """Returns the resource from the Node type. Overwrite this function for each node type
+        """Returns the resource from the Node type. Overwrite this function for each node type.
         """
         # print("This is the base Node functionality, overwite for each childNode to import the relevant resource type")
 
     def set_resource(self,value):
-        """sets the resource for the Node type. Overwrite this function for each node type
+        """sets the resource for the Node type. Overwrite this function for each node type.
         """
         # print("This is the base Node functionality, overwite for each childNode to import the relevant resource type")
 
 
     def clear_resource(self):
-        """Clear all geometries (images, pcd, meshes, ortho's, etc.) in the Node.
+        """Clear all resources (images, pcd, meshes, ortho's, etc.) in the Node.
         """
         if getattr(self,'resource',None) is not None:
             self.resource=None
@@ -398,10 +429,11 @@ class Node:
         #     self.ortho=None
             
     def get_path(self) -> str:
-        """Find the full path of the resource from this Node.\n
+        """Returns the full path of the resource from this Node.\n
 
-        Valid inputs are:\n
-            self._graphPath and (self._name or self._subject)
+        Features:
+            1. self.graphPath\n
+            2. self._name or self._subject\n
 
         Returns:
             path (str)
@@ -428,10 +460,11 @@ class Node:
             return None
 
     def get_graph(self):
-        """Returns the graph of the Node.\n
+        """Returns the graph of the Node.
 
-        Valid inputs are:\n
-            self._graphPath and/or self._subject)\n
+        Features:
+            1. self.graphPath\n
+            2. self._subject\n
 
         Returns:
             graph (RDFlib.GRAPH)
@@ -446,12 +479,12 @@ class Node:
         return self._graph
 
     def to_graph(self, graphPath : str = None, overwrite:bool=True,save:bool=False) -> Graph:
-        """Converts the current Node variables to a graph and optionally save it
+        """Converts the current Node variables to a graph and optionally save.
 
         Args:
-            graphPath (str, optional): The full path to write the graph to. Defaults to None.\n
-            overwrite (bool, optional=True): Overwrite current graph values or not\n
-            save (bool, optional=False): Save the graph to the self.graphPath or graphPath.\n
+            1. graphPath (str, optional): The full path to write the graph to. Defaults to None.\n
+            2. overwrite (bool, optional=True): Overwrite current graph values or not\n
+            3. save (bool, optional=False): Save the graph to the self.graphPath or graphPath.\n
         """
         if graphPath and next(graphPath.endswith(extension) for extension in ut.RDF_EXTENSIONS) :
             self._graphPath=graphPath
@@ -506,19 +539,19 @@ class Node:
         return self._graph
 
     def save_graph(self,graphPath : str = None) -> bool:
-        """Serialize the graph in an RDF file on drive.\n
-        The RDF graph will be stored in self._graphPath or provided graphPath (str)
+        """Serialize the graph in an RDF file on drive.
+        The RDF graph will be stored in self.graphPath or provided graphPath (str).
 
         Args:
-            graphPath (str, optional): Defaults to None.\n
+            graphPath (str, optional)\n
 
         Raises:
             ValueError: No valid graphPath if file/folder location is not found\n
             ValueError: No valid extension if not in ut.RDF_EXTENSIONS\n
-            ValueError: Save failed despite valid graphPath and extension (serialization error).
+            ValueError: Save failed despite valid graphPath and extension (serialization error).\n
 
         Returns:
-            bool: True if file is succesfully saved
+            bool: True if file is succesfully saved.
         """
         #check path validity
         if(graphPath and ut.check_if_path_is_valid(graphPath)): 
