@@ -61,16 +61,16 @@ class PointCloudNode (GeometryNode):
         self.pointCount=None
         self.e57XmlPath=None
 
+        #instance variables
+        self.e57Index = e57Index
+        self.e57XmlPath = e57XmlPath
+
         super().__init__(   graph= graph,
                             graphPath= graphPath,
                             subject= subject,
                             path=path,
                             **kwargs)    
 
-        #instance variables
-        self.e57Index = e57Index
-        self.e57XmlPath = e57XmlPath
-
         #initialisation functionality
         if getResource:
             self.get_resource()
@@ -127,10 +127,14 @@ class PointCloudNode (GeometryNode):
         else:
             raise ValueError('Resource must be an o3d.geometry.PointCloud with len(resource.points) >=3 or an pye57.e57.E57 instance.')
 
-    def get_resource(self) -> o3d.geometry.PointCloud:
+    def get_resource(self, percentage:float=0.1) -> o3d.geometry.PointCloud:
         """Returns the pointcloud data in the node. \n
         If none is present, it will search for the data on drive from path, graphPath, name or subject. 
 
+        Args:
+            1. self (pointCloudNode)\n
+            2. percentage (float,optional): percentage of point cloud to load. Defaults to 1.0 (100%).\n
+
         Returns:
             o3d.geometry.PointCloud or None
         """
@@ -139,10 +143,11 @@ class PointCloudNode (GeometryNode):
         elif self.get_path():
             if self.path.endswith('pcd'):
                 resource =  o3d.io.read_point_cloud(self.path)
+                resource = resource.random_down_sample(percentage)
                 if len(resource.points)>3:
                     self._resource  =resource
             elif self.path.endswith('e57'):
-                self._resource  =gt.e57path_to_pcd(self.path, self.get_e57Index()) 
+                self._resource  =gt.e57path_to_pcd(self.path, self.get_e57Index(),percentage=percentage) 
         return self._resource  
 
     def save_resource(self, directory:str=None,extension :str = '.pcd') ->bool:
@@ -158,36 +163,35 @@ class PointCloudNode (GeometryNode):
         Returns:
             bool: return True if export was succesful
         """        
-        #check path
+        #check resource
         if self.resource is None:
             return False
 
+        #validate extension
+        if extension not in ut.PCD_EXTENSION:
+            raise ValueError('Invalid extension')
+
         # check if already exists
         if directory and os.path.exists(os.path.join(directory,self.get_name() + extension)):
+            self.path=os.path.join(directory,self.get_name() + extension)
             return True
         elif not directory and self.get_path() and os.path.exists(self.path) and extension in ut.MESH_EXTENSION:
-            return True
+            return True        
                    
-        #get directory
-        if (directory):
-            pass    
-        elif self.path is not None:    
-            directory=ut.get_folder(self.path)            
-        elif(self.graphPath): 
-            dir=ut.get_folder(self.graphPath)
-            directory=os.path.join(dir,'PCD')   
+        #get path        
+        if directory:
+            self.path=os.path.join(directory,self.get_name() + extension)
         else:
-            directory=os.path.join(os.getcwd(),'PCD')
-        # create directory if not present
-        if not os.path.exists(directory):                        
-            os.mkdir(directory)       
+            if self.get_path():
+                pass
+            elif(self.graphPath): 
+                dir=ut.get_folder(self.graphPath)
+                directory=os.path.join(dir,'PCD')   
+                self.path=os.path.join(dir,self.get_name() + extension)
+            else:
+                directory=os.path.join(os.getcwd(),'PCD')
+                self.path=os.path.join(dir,self.get_name() + extension)
 
-        #check extension
-        if extension in ut.PCD_EXTENSION:
-            self.path=os.path.join(directory,ut.get_filename(self.subject.toPython()) + extension)
-        else:
-            raise ValueError('Erroneous extension ')
-       
         #write files
         if self.path.endswith('.e57'):
             data3D=gt.get_data3d_from_pcd(self.resource)
