@@ -10,6 +10,7 @@ import open3d as o3d
 import os 
 import re
 import pye57 #conda install xerces-c  =>  pip install pye57
+
 import xml.etree.ElementTree as ET 
 from typing import List,Tuple
 
@@ -27,6 +28,7 @@ import ifcopenshell.geom as geom
 import ifcopenshell.util
 from ifcopenshell.util.selector import Selector
 import multiprocessing
+import concurrent.futures
 
 #IMPORT MODULES 
 from geomapi.nodes import *
@@ -90,6 +92,65 @@ def img_xml_to_nodes(xmlPath :str, **kwargs) -> List[ImageNode]:
     else:
         raise ValueError('No valid xmlPath.')
 
+def e57path_to_nodes(e57Path:str,percentage:float=1.0) ->List[PointCloudNode]:
+    """Load an e57 file and convert all data to a list of PointCloudNodes.\n
+
+    **NOTE**: lowering the percentage barely affects assignment performance (numpy array assignments are extremely efficient). \n 
+    Only do this to lower computational complexity or free up memory.
+
+    Args:
+        1. e57path(str): absolute path to .e57 file\n
+        2. percentage(float,optional): percentage of points to load. Defaults to 1.0 (100%)\n
+
+    Returns:
+        o3d.geometry.PointCloud
+    """    
+    e57 = pye57.E57(e57Path)
+    nodes=[]
+    for s in range(e57.scan_count):
+        resource=gt.e57_to_pcd(e57,e57Index=s,percentage=percentage)
+        node=PointCloudNode(resource=resource,
+                            path=e57Path,
+                            e57Index=s,
+                            percentage=percentage)
+        node.pointCount=len(resource.points)
+        nodes.append(node)
+    return nodes
+    
+def e57path_to_nodes_mutiprocessing(e57Path:str,percentage:float=1.0) ->List[PointCloudNode]:
+    """Load an e57 file and convert all data to a list of PointCloudNodes.\n
+
+    **NOTE**: Complex types cannot be pickled (serialized) by Windows. Therefore, a two step parsing is used where e57 data is first loaded as np.arrays with multi-processing.
+    Next, the arrays are passed to o3d.geometry.PointClouds outside of the loop.\n  
+
+    **NOTE**: starting parallel processing takes a bit of time. This method will start to outperform single-core import from 3+ pointclouds.\n
+
+    **NOTE**: lowering the percentage barely affects assignment performance (numpy array assignments are extremely efficient). \n 
+    Only do this to lower computational complexity or free up memory.
+
+    Args:
+        1. e57path(str): absolute path to .e57 file\n
+        2. percentage(float,optional): percentage of points to load. Defaults to 1.0 (100%)\n
+
+    Returns:
+        o3d.geometry.PointCloud
+    """    
+    e57 = pye57.E57(e57Path)
+    nodes=[]
+    with concurrent.futures.ProcessPoolExecutor() as executor:
+        # first load all e57 data and output it as np.arrays
+        results=[executor.submit(gt.e57_to_arrays,e57Path=e57Path,e57Index=s,percentage=percentage) for s in range(e57.scan_count)]
+        # next, the arrays are assigned to point clouds outside the loop.
+        for s,r in enumerate(concurrent.futures.as_completed(results)):
+            resource=gt.arrays_to_pcd(r.result())
+            node=PointCloudNode(resource=resource,
+                                path=e57Path,
+                                e57Index=s,
+                                percentage=percentage)
+            node.pointCount=len(resource.points)
+            nodes.append(node)
+    return nodes
+
 def e57header_to_nodes(e57Path:str, **kwargs) -> List[PointCloudNode]:
     """
     Parse e57 file header that is created with E57lib e57xmldump.exe.
