@@ -58,9 +58,9 @@ def replace_str_index(text:str,index:int,replacement:str='_'):
     """Replace a string character at the location of the index with the replacement.\n
 
     Args:
-        0. text (str)\n
-        1. index (int): index to replace. \n
-        2. replacement (str, optional): replacement character. Defaults to '_'.\n
+        1. text (str)\n
+        2. index (int): index to replace. \n
+        3. replacement (str, optional): replacement character. Defaults to '_'.\n
 
     Returns:
         text (str) with updated characters
@@ -100,7 +100,8 @@ def get_list_of_files(directoryPath:str) -> list:
     """Get a list of all filepaths in the directory and subdirectories.\n
 
     Args:
-        directoryPath: directory path e.g. "D:\\Data\\2018-06 Werfopvolging Academiestraat Gent\\week 22\\"
+        directoryPath: directory path e.g. \n
+            "D:\\Data\\2018-06 Werfopvolging Academiestraat Gent\\week 22\\"
             
     Returns:
         A list of filepaths
@@ -147,7 +148,7 @@ def get_subject_graph(graph:Graph, subject:URIRef = None) -> Graph:
             return None
 
 def get_paths_in_class(cls) -> list: 
-    """returns list of path attributes in the class.\n
+    """Returns list of path attributes in the class.\n
 
     Args:
         cls (class): class e.g. MeshNode
@@ -208,10 +209,10 @@ def dms2dd(degrees:float, minutes:float, seconds:float, direction:str) -> float:
         dd *= -1
     return dd
 
-def dd2dms(deg) -> List[float,float,float]:
+def dd2dms(deg) -> List[float]:
     """Convert decimal degrees to List[degrees, minutes, seconds] notation. \n
 
-    **NOTE**: Direction is not determined (should be easy based on sign.)
+    **NOTE**: Direction is not determined (should be easy based on sign).
 
     Args:
         decimal degrees (float)
@@ -261,6 +262,8 @@ def get_exif_data(img:PIL.Image)-> dict:
     """Returns a dictionary from the exif data of an Image (PIL) item. Also
     converts the GPS Tags.\n
 
+    https://pillow.readthedocs.io/en/stable/reference/Image.html
+    
     Args:
         Img (PIL.image)
     
@@ -286,7 +289,7 @@ def get_exif_data(img:PIL.Image)-> dict:
         return None        
 
 def get_filename(path :str) -> str:
-    """ Deconstruct filepath and return filename
+    """ Deconstruct filepath and return filename.
     
     Args:
         path (str): filepath
@@ -311,7 +314,7 @@ def get_folder(path :str) -> str:
     return os.path.dirname(os.path.realpath(path))
 
 def get_timestamp(path : str) -> str:
-    """Returns the timestamp ('%Y-%m-%dT%H:%M:%S') from a filepath
+    """Returns the timestamp ('%Y-%m-%dT%H:%M:%S') from a filepath.
 
     Args:
         path (str): filepath
@@ -330,9 +333,9 @@ def literal_to_cartesianTransform(literal:Literal) -> np.array:
 
     Args:
         literal (URIRef):  stringed list or np array of the cartesianTransform e.g. \n
-            e57:cartesianTransform ""[[ 3.48110207e-01  9.37407536e-01  9.29487057e-03  2.67476305e+01]\n
-                                    [-9.37341584e-01  3.48204779e-01 -1.20077869e-02  6.17326932e+01]\n
-                                    [-1.44927083e-02 -4.53243552e-03  9.99884703e-01  4.84636987e+00]\n
+            e57:cartesianTransform ""[[ 3.48110207e-01  9.37407536e-01  9.29487057e-03  2.67476305e+01]
+                                    [-9.37341584e-01  3.48204779e-01 -1.20077869e-02  6.17326932e+01]
+                                    [-1.44927083e-02 -4.53243552e-03  9.99884703e-01  4.84636987e+00]
                                     [ 0.00000000e+00  0.00000000e+00  0.00000000e+00  1.00000000e+00]]""
 
     Returns:
@@ -440,7 +443,7 @@ def literal_to_string(literal: Literal)->str:
         raise ValueError
 
 def literal_to_list(literal: Literal)->list:
-    """Returns list from rdflib.literal 
+    """Returns list from rdflib.literal.
 
     Args:
         literal (rdflib): literal containing value
@@ -461,7 +464,7 @@ def literal_to_list(literal: Literal)->list:
         raise ValueError
 
 def literal_to_int(literal: Literal) -> int:
-    """Returns int from rdflib.literal 
+    """Returns int from rdflib.literal.
 
     Args:
         literal (rdflib): literal containing value
@@ -480,7 +483,7 @@ def literal_to_int(literal: Literal) -> int:
         raise ValueError ('Conversion error')
 
 def literal_to_uriref(literal: Literal)->URIRef:
-    """Returns rdflib.URIRef from rdflib.literal 
+    """Returns rdflib.URIRef from rdflib.literal.
 
     Args:
         literal (rdflib): literal containing value
@@ -552,13 +555,11 @@ def get_graph_intersection(graphs:List[Graph]) -> Graph:
     return selectGraph
 
 def get_graph_subject(graph:Graph,subject:URIRef) ->URIRef:
-    """Returns graph subject with its appropriate prefix given the main body of a subject.\n
-    This function is mainly used for local file serializations that mud the graph subjects.\n
-    You can then use this function to use the correct graph subject regardless of the prefix.\n
+    """Returns graph subject with its appropriate prefix given the main body of a subject. This function is mainly used for local file serializations that mud the graph subjects. You can then use this function to use the correct graph subject regardless of the prefix.\n
 
     Args:
-        graph (Graph): graph with subjects with prefix e.g. URIRef(D:\\DATA\\Subject1)
-        subject (URIRef): subject to search for. e.g. URIREF(Subject1)
+        1. graph (Graph): graph with subjects with prefix e.g. URIRef(D:\\DATA\\Subject1)\n
+        2. subject (URIRef): subject to search for. e.g. URIREF(Subject1)\n
 
     Raises:
         ValueError: 'subject not in graph.'
@@ -638,7 +639,7 @@ def string_to_rotation_matrix(string :str) -> np.array:
         raise ValueError('array.size!=9')
 
 def xml_to_float(xml) -> float:
-    """Cast XML string value to float if possible
+    """Cast XML string value to float if possible.
 
     Args:
         xml value
@@ -804,7 +805,7 @@ def validate_string(string:str, replacement ='_') -> str:
     return string
 
 def is_float(element) -> bool:
-    """Returns True if Python value is a float
+    """Returns True if Python value is a float.
 
     Args:
         element (Python value)
@@ -819,7 +820,7 @@ def is_float(element) -> bool:
         return False
 
 def is_int(element) -> bool:
-    """Returns True if Python value is an int
+    """Returns True if Python value is an int.
 
     Args:
         element (Python value)
@@ -834,7 +835,7 @@ def is_int(element) -> bool:
         return False
 
 def is_string(element) -> bool:
-    """Returns True if Python value is a str
+    """Returns True if Python value is a str.
 
     Args:
         element (Python value)
@@ -850,7 +851,7 @@ def is_string(element) -> bool:
         return False
 
 def is_uriref(element) -> bool:
-    """Returns True if Python value is a rdflib.URIRef
+    """Returns True if Python value is a rdflib.URIRef.
 
     Args:
         element (Python value)
@@ -870,7 +871,7 @@ def is_uriref(element) -> bool:
 # #### RDF ####
 
 def get_attribute_from_predicate(graph: Graph, predicate : Literal) -> str:
-    """Returns the attribute witout the namespace
+    """Returns the attribute witout the namespace.
 
     Args:
         graph (Graph): The Graph containing the namespaces
@@ -931,8 +932,7 @@ def bind_ontologies(graph : Graph) -> Graph:
     return graph
 
 def clean_attributes_list(list:list) -> list:
-    """Returns a 'cleaned' list of class attributes that are not to be serialized in the graph.\n
-    This includes data attributes such as resources (point clouds, images), linkedNodes, etc.\n
+    """Returns a 'cleaned' list of class attributes that are not to be serialized in the graph. This includes data attributes such as resources (point clouds, images), linkedNodes, etc.\n
 
     **NOTE**: RDF Graphs are meant to store metadata, not actual GBs of data that should be contained in their native file formats.\n
 
