@@ -5,6 +5,7 @@ Geometryutils - a Python library for processing mesh and point cloud data.
 from ast import Raise
 from logging import warning
 from operator import ge
+from re import X
 from xmlrpc.client import Boolean
 import numpy as np 
 import open3d as o3d 
@@ -135,7 +136,7 @@ def mesh_to_trimesh(geometry: o3d.geometry) -> trimesh.Trimesh:
         raise ValueError('Incorrect geometry input. Only input o3d.geometry.TriangleMesh,o3d.geometry.AxisAlignedBoundingBox or o3d.geometry.OrientedBoundingBox or type(geometry)  ')
 
 def crop_geometry_by_convex_hull(source:trimesh.Trimesh, cutters: List[trimesh.Trimesh], inside : Boolean = True ) -> trimesh.Trimesh:
-    """"Cut a portion of a mesh that lies within the convex hull of another mesh.\n
+    """Cut a portion of a mesh that lies within the convex hull of another mesh.
     
     .. image:: ../../../docs/pics/crop_by_convex_hull.PNG
 
@@ -213,7 +214,7 @@ def get_mesh_representation(geometry)->o3d.geometry.TriangleMesh:
         raise ValueError('No valid input: o3d.geometry.TriangleMesh or o3d.geometry.PointCloud')
 
 def get_mesh_collisions_trimesh(sourceMesh: o3d.geometry.TriangleMesh, geometries: List[o3d.geometry.TriangleMesh]) -> List[int]:
-    """Return indices of geometries that collide with the source.\n
+    """Return indices of geometries that collide with the source.
 
     .. image:: ../../../docs/pics/collision_4.PNG
 
@@ -322,6 +323,26 @@ def arrays_to_pcd(tuple) -> o3d.geometry.PointCloud:
         pointcloud.transform(tuple[3])  
     return pointcloud
 
+def e57_get_cartesian_transform(header:dict)->np.array:
+    """Returns cartesianTransform (np.array(4x4)) from a e57 header
+
+    Args:
+        header (dict): retrieved from pye57 e57.get_header(e57Index)
+
+    Returns:
+        cartesianTransform (np.array(4x4))
+    """
+    cartesianTransform=np.diag(np.diag(np.ones((4,4))))    
+    if 'pose' in header.scan_fields:
+        rotation_matrix=None
+        translation=None
+        if getattr(header,'rotation',None) is not None:
+                rotation_matrix=header.rotation_matrix
+        if getattr(header,'translation',None) is not None:
+            translation=header.translation
+        cartesianTransform=get_cartesian_transform(rotation=rotation_matrix,translation=translation)
+    return  cartesianTransform
+
 def e57_to_pcd(e57:pye57.e57.E57,e57Index : int = 0,percentage:float=1.0)->o3d.geometry.PointCloud:
     """Convert a scan from a pye57.e57.E57 file to o3d.geometry.PointCloud
 
@@ -333,56 +354,47 @@ def e57_to_pcd(e57:pye57.e57.E57,e57Index : int = 0,percentage:float=1.0)->o3d.g
     Returns:
         o3d.geometry.PointCloud
     """
-    #get transformation
-    cartesianTransform=np.diag(np.diag(np.ones((4,4))))
+    #get header
     header = e57.get_header(e57Index)
-    if 'pose' in header.scan_fields:
-        rotation_matrix=None
-        translation=None
-        if getattr(header,'rotation',None) is not None:
-                rotation_matrix=header.rotation_matrix
-        if getattr(header,'translation',None) is not None:
-            translation=header.translation
-        cartesianTransform=get_cartesian_transform(rotation=rotation_matrix,translation=translation)
-    #get raw geometry (no transformation)
-    raw_data = e57.read_scan_raw(e57Index)    
-    if all(elem in header.point_fields  for elem in ['cartesianX', 'cartesianY', 'cartesianZ']):   
-        x_ndarray=raw_data.get('cartesianX')
-        y_ndarray=raw_data.get('cartesianY')
-        z_ndarray=raw_data.get('cartesianZ')
-        array=np.vstack(( x_ndarray,y_ndarray,z_ndarray)).flatten('F')
-        array= np.reshape(array,(len(x_ndarray),3))
-        
-        #downnsample
-        if percentage <1.0:
-            indices=np.random.randint(0,len(array)-1,int(len(array)*percentage))
-            array=array[indices]
+    
+    #get transformation
+    cartesianTransform=e57_get_cartesian_transform(header)
 
-        #create point cloud
-        points = o3d.utility.Vector3dVector(array)
-        pcd=o3d.geometry.PointCloud(points)
-        pcd.transform(cartesianTransform)            
+    #get raw geometry (no transformation)
+    rawData = e57.read_scan_raw(e57Index)    
+    if all(elem in header.point_fields  for elem in ['cartesianX', 'cartesianY', 'cartesianZ']):   
+        pointArray=e57_get_xyz_from_raw_data(rawData)
+    elif all(elem in header.point_fields  for elem in ['sphericalRange', 'sphericalAzimuth', 'sphericalElevation']):   
+        pointArray=e57_get_xyz_from_spherical_raw_data(rawData)
+    else:
+        raise ValueError('e57 rawData parsing failed.')
+
+    #downnsample
+    if percentage <1.0:
+        indices=np.random.randint(0,len(pointArray)-1,int(len(pointArray)*percentage))
+        pointArray=pointArray[indices]
+
+    #create point cloud
+    points = o3d.utility.Vector3dVector(pointArray)
+    pcd=o3d.geometry.PointCloud(points)
 
     #get color or intensity
     if (all(elem in header.point_fields  for elem in ['colorRed', 'colorGreen', 'colorBlue'])
         or 'intensity' in header.point_fields ): 
-        colors=e57_get_colors(raw_data)
+        colors=e57_get_colors(rawData)
         if percentage <1.0:
             colors=colors[indices]
         pcd.colors=o3d.utility.Vector3dVector(colors) 
 
     #get normals
     if all(elem in header.point_fields  for elem in ['nor:normalX', 'nor:normalY', 'nor:normalZ']): 
-        nx_ndarray=raw_data.get('nor:normalX')
-        ny_ndarray=raw_data.get('nor:normalY')
-        nz_ndarray=raw_data.get('nor:normalZ')
-        array= np.reshape(np.vstack(( nx_ndarray,ny_ndarray,nz_ndarray)).flatten('F'),(len(x_ndarray),3))
+        normals=e57_get_normals(rawData)
         if percentage <1.0:
-            array=array[indices]
-        normals = o3d.utility.Vector3dVector(array)
-        pcd.normals=normals
+            normals=normals[indices]
+        pcd.normals=o3d.utility.Vector3dVector(normals)
 
     #return transformed data
+    pcd.transform(cartesianTransform)    
     return pcd
 
 def arrays_to_mesh(tuple) -> o3d.geometry.TriangleMesh:
@@ -499,50 +511,51 @@ def pcd_to_arrays(path:str,percentage:float=1.0,tasknr:int=0)->Tuple[np.array,np
 
     return pointArray,colorArray,normalArray,tasknr
 
-def e57_get_xyz_from_spherical_raw_data(raw_data: dict) -> np.array:
-    """
-    Converts spherical(rae) to cartesian(xyz), where rae = range, azimuth(theta), 
-    elevation(phi). Where range is in meters and angles are in radians.
+def e57_get_xyz_from_spherical_raw_data(rawData: dict) -> np.array:
+    """Converts spherical(rae) to cartesian(xyz), where rae = range, azimuth(theta), 
+    elevation(phi). Where range is in meters and angles are in radians.\n
     
-    Reference for formula: http://www.libe57.org/bestCoordinates.html (Note: the 
-    formula is different from the one online, so please use formula at the above reference)
+    Reference for formula: http://www.libe57.org/bestCoordinates.html \n
 
     Args:
-        raw_data (e57 dict):  raw_data = e57.read_scan_raw(e57Index)   
+        rawData (e57 dict):  rawData = e57.read_scan_raw(e57Index)   
         
     Returns:
         np.array (nx3): XYZ cartesian coordinates np.array
     """
-    range = raw_data.get('sphericalRange')
-    theta = raw_data.get('sphericalAzimuth')
-    phi =  raw_data.get('sphericalElevation')
+    range = rawData.get('sphericalRange')
+    theta = rawData.get('sphericalAzimuth')
+    phi =  rawData.get('sphericalElevation')
     range_cos_phi = range * np.cos(phi)
-    pointArray= np.concatenate((
-        range_cos_phi * np.cos(theta),
-        range_cos_phi * np.sin(theta),
-        range * np.sin(phi)
-    ), axis=1)
-    pointArray=np.reshape(pointArray.flatten('F'),(len(pointArray),3))
+    # pointArray= np.concatenate((
+    #     range_cos_phi * np.cos(theta),
+    #     range_cos_phi * np.sin(theta),
+    #     range * np.sin(phi)
+    # ), axis=1)
+    # pointArray=np.reshape(pointArray.flatten('F'),(len(pointArray),3))
+
+    pointArray=np.reshape(np.vstack( range_cos_phi * np.cos(theta),
+                                    range_cos_phi * np.sin(theta),
+                                    range * np.sin(phi)).flatten('F'),(len(range),3))
     return pointArray
 
-def e57_get_xyz_from_raw_data(raw_data: dict)->np.array:
+def e57_get_xyz_from_raw_data(rawData: dict)->np.array:
     """returns xyz coordinates from e57 raw data.\n
 
     Args:
-        raw_data (e57 dict):  raw_data = e57.read_scan_raw(e57Index)   
+        rawData (e57 dict):  rawData = e57.read_scan_raw(e57Index)   
         
     Returns:
         np.array (nx3): XYZ cartesian coordinates np.array
     """
-    x_ndarray=raw_data.get('cartesianX')
-    y_ndarray=raw_data.get('cartesianY')
-    z_ndarray=raw_data.get('cartesianZ') 
-    pointArray= np.concatenate((x_ndarray,y_ndarray,z_ndarray), axis=1) 
-    pointArray=np.reshape(pointArray.flatten('F'),(len(pointArray),3))
+    x=rawData.get('cartesianX')
+    y=rawData.get('cartesianY')
+    z=rawData.get('cartesianZ') 
+    pointArray=np.reshape(np.vstack(( x,y,z)).flatten('F'),(len(x),3))
     return pointArray
 
 def e57_get_cartesianTransform(header)-> np.array:
-    """Returns the cartesianTransform from an e57 header 
+    """Returns the cartesianTransform from an e57 header.\n
 
     Args:
         header (e57): rotation and translation should be present.
@@ -582,16 +595,15 @@ def e57_to_arrays(e57Path:str,e57Index : int = 0,percentage:float=1.0,tasknr:int
     """
     e57 = pye57.E57(e57Path)
     #get transformation
-    cartesianTransform=np.diag(np.diag(np.ones((4,4))))
     header = e57.get_header(e57Index)
     cartesianTransform= e57_get_cartesianTransform(header)
     
     #get points    
-    raw_data = e57.read_scan_raw(e57Index)    
+    rawData = e57.read_scan_raw(e57Index)    
     if all(elem in header.point_fields  for elem in ['cartesianX', 'cartesianY', 'cartesianZ']):   
-        pointArray=e57_get_xyz_from_raw_data(raw_data)
+        pointArray=e57_get_xyz_from_raw_data(rawData)
     elif all(elem in header.point_fields  for elem in ['sphericalRange', 'sphericalAzimuth', 'sphericalElevation']):
-        pointArray=e57_get_xyz_from_spherical_raw_data(raw_data)
+        pointArray=e57_get_xyz_from_spherical_raw_data(rawData)
 
     #downnsample
     if percentage <1.0:
@@ -602,43 +614,14 @@ def e57_to_arrays(e57Path:str,e57Index : int = 0,percentage:float=1.0,tasknr:int
     colorArray=None
     if (all(elem in header.point_fields  for elem in ['colorRed', 'colorGreen', 'colorBlue'])
         or 'intensity' in header.point_fields ): 
-        
-        colorRed=raw_data.get('colorRed')
-        colorGreen=raw_data.get('colorGreen')
-        colorBlue=raw_data.get('colorBlue')
-        intensity=raw_data.get('intensity')
-
-        if colorRed is not None and colorGreen is not None and colorBlue is not None:
-            if np.amax(colorRed)<=1:
-                colors=np.c_[colorRed , colorGreen,colorBlue ]  
-            elif np.amax(colorRed) <=255:
-                colors=np.c_[colorRed/255 , colorGreen/255,colorBlue/255 ]  
-            else:
-                colorRed=(colorRed - np.min(colorRed))/np.ptp(colorRed)
-                colorGreen=(colorGreen - np.min(colorGreen))/np.ptp(colorGreen)
-                colorBlue=(colorBlue - np.min(colorBlue))/np.ptp(colorBlue)
-                colors=np.c_[colorRed , colorGreen,colorBlue ]  
-            colorArray=np.reshape(colors.flatten('F'),(len(colorRed),3))
-            if percentage <1.0:
-                colorArray=colorArray[indices]
-
-        elif intensity is not None:
-            if np.amax(intensity) <=1:
-                colors=np.c_[intensity , intensity,intensity ]  
-            else:
-                intensity=(intensity - np.min(intensity))/np.ptp(intensity)
-                colors=np.c_[intensity , intensity,intensity ]  
-            colorArray=np.reshape(colors,(len(intensity),3))
-            if percentage <1.0:
-                colorArray=colorArray[indices]
+        colorArray=e57_get_colors(rawData)
+        if percentage <1.0:
+            colorArray=colorArray[indices]
 
     #get normals
     normalArray=None
     if all(elem in header.point_fields  for elem in ['nor:normalX', 'nor:normalY', 'nor:normalZ']): 
-        nx_ndarray=raw_data.get('nor:normalX')
-        ny_ndarray=raw_data.get('nor:normalY')
-        nz_ndarray=raw_data.get('nor:normalZ')
-        normalArray= np.reshape(np.vstack(( nx_ndarray,ny_ndarray,nz_ndarray)).flatten('F'),(len(nx_ndarray),3))
+        normalArray=e57_get_normals(rawData)
         if percentage <1.0:
             normalArray=normalArray[indices]
 
@@ -698,6 +681,14 @@ def e57path_to_pcds_multiprocessing(e57Path:str,percentage:float=1.0) ->List[o3d
     return pcds
 
 def box_to_mesh(box:o3d.geometry) ->o3d.geometry.TriangleMesh:
+    """Returns o3d.geometry.TriangleMesh of OrientedBoundingBox or AxisAlignedBoundingBox. \n
+
+    Args:
+        box (o3d.geometry.OrientedBoundingBox or AxisAlignedBoundingBox)
+
+    Returns:
+        o3d.geometry.TriangleMesh
+    """
     if type(box) is o3d.geometry.OrientedBoundingBox or type(box) is o3d.geometry.AxisAlignedBoundingBox:
         mesh=o3d.geometry.TriangleMesh()
         mesh.vertices=box.get_box_points()
@@ -806,7 +797,7 @@ def generate_visual_cone_from_image(cartesianTransform : np.array, height : floa
 def get_cartesian_transform(rotation: np.array= None, 
                             translation:  np.array=  None,
                             cartesianBounds:  np.array= None ) -> np.ndarray:
-    """Return cartesianTransform from rotation, translation or cartesianBounds inputs
+    """Return cartesianTransform from rotation, translation or cartesianBounds inputs.\n
 
     Args:
         1. rotation (np.array[3x3]) : rotation matrix\n
@@ -946,20 +937,35 @@ def generate_virtual_image(geometries: List[o3d.geometry.Geometry],pinholeCamera
         return None
 
 #### GEOMETRY MANIPULATION ####
-def e57_get_colors(raw_data: dict):
+def e57_get_normals(rawData:dict)->np.array:
+    """Returns normal vectors from e57 rawData.
+
+    Args:
+        rawData (dict): e57 dictionary resulting from e57.read_scan_raw(e57Index)\n
+
+    Returns:
+         np.array(nx3): magnitude 1
+    """
+    
+    nx=rawData.get('nor:normalX')
+    ny=rawData.get('nor:normalY')
+    nz=rawData.get('nor:normalZ')
+    return np.reshape(np.vstack(( nx,ny,nz)).flatten('F'),(len(nx),3))
+    
+def e57_get_colors(rawData: dict)->np.array:
     """Extract color of intensity information from e57 raw data (3D data) and output Open3D o3d.utility.Vector3dVector(colors).\n
 
     Args:
-        raw_data(dict): e57 dictionary resulting from e57.read_scan_raw(e57Index)\n
+        rawData(dict): e57 dictionary resulting from e57.read_scan_raw(e57Index)\n
     
     Returns:
         np.array(nx3): RGB or intensity color information. RGB is prioritised.
     """   
     try:
-        colorRed=raw_data.get('colorRed')
-        colorGreen=raw_data.get('colorGreen')
-        colorBlue=raw_data.get('colorBlue')
-        intensity=raw_data.get('intensity')
+        colorRed=rawData.get('colorRed')
+        colorGreen=rawData.get('colorGreen')
+        colorBlue=rawData.get('colorBlue')
+        intensity=rawData.get('intensity')
 
         if colorRed is not None and colorGreen is not None and colorBlue is not None:
             if np.amax(colorRed)<=1:
@@ -971,7 +977,7 @@ def e57_get_colors(raw_data: dict):
                 colorGreen=(colorGreen - np.min(colorGreen))/np.ptp(colorGreen)
                 colorBlue=(colorBlue - np.min(colorBlue))/np.ptp(colorBlue)
                 colors=np.c_[colorRed , colorGreen,colorBlue ]  
-            return colors
+            return np.reshape(colors.flatten('F'),(len(colorRed),3))
 
         elif intensity is not None:
             if np.amax(intensity) <=1:
@@ -979,14 +985,13 @@ def e57_get_colors(raw_data: dict):
             else:
                 intensity=(intensity - np.min(intensity))/np.ptp(intensity)
                 colors=np.c_[intensity , intensity,intensity ]  
-            return colors
+            return np.reshape(colors.flatten('F'),(len(intensity),3))
     except:
         return None
     return None
 
 def e57_fix_rotation_order(rotation_matrix:np.array) -> np.array:
-    """Switch the rotation from clockwise to counter-clockwise in e57 rotation matrix.\n
-    See following url for more information:\n
+    """Switch the rotation from clockwise to counter-clockwise in e57 rotation matrix. See following url for more information:\n
 
     https://robotics.stackexchange.com/questions/10702/rotation-matrix-sign-convention-confusion\n
     
@@ -1051,13 +1056,13 @@ def get_matching_indices(source, target, trans, search_voxel_size, K=None):
 #     return correspondences
 
 def crop_geometry_by_box(geometry:o3d.geometry, box:o3d.geometry.OrientedBoundingBox, subdivide:int = 0) ->o3d.geometry:
-    """"Crop portion of a mesh/pointcloud that lies within an OrientedBoundingBox.\n
+    """Crop portion of a mesh/pointcloud that lies within an OrientedBoundingBox.
 
     .. image:: ../../../docs/pics/selection_BB_mesh2.PNG
 
     Args:
         1. geometry (o3d.geometry.TriangleMesh or o3d.geometry.PointCloud): Geometry to be cropped\n
-        2. box (o3d.geometry.OrientedBoundingBox ): bouding cutter geometry\n
+        2. box (o3d.geometry.OrientedBoundingBox): bouding cutter geometry\n
         3. subdivide (int): number of interations to increase the density of the mesh (1=x4, 2=x16, etc.)\n
         
     Returns:
@@ -1096,7 +1101,7 @@ def crop_geometry_by_box(geometry:o3d.geometry, box:o3d.geometry.OrientedBoundin
         return None
 
 def expand_box (box: o3d.geometry.OrientedBoundingBox, u=5.0,v=5.0,w=5.0) -> o3d.geometry.OrientedBoundingBox:
-    """expand an o3d.geometry.OrientedBoundingBox in u(x), v(y) and w(z) direction with a certain offset
+    """expand an o3d.geometry.OrientedBoundingBox in u(x), v(y) and w(z) direction with a certain offset.
 
     Args:
         1. box (o3d.geometry.OrientedBoundingBox)\n
@@ -1145,13 +1150,11 @@ def join_geometries(geometries) ->o3d.geometry:
         raise ValueError('Only submit o3d.geometry.TriangleMesh or o3d.geometry.PointCloud objects') 
 
 def create_visible_point_cloud_from_meshes (geometries: List[o3d.geometry.TriangleMesh], references:List[o3d.geometry.TriangleMesh], resolution:float = 0.1)-> Tuple[List[o3d.geometry.PointCloud], List[float]]:
-    """Returns a set of point clouds sampled on the geometries.\n
-    Each point cloud has its points filtered to not lie wihtin or collide with any of the reference geometries. \n
-    As such, this method returns the **visible** parts of a set of sampled point clouds. \n
-    For every point cloud, the percentage of visibility is also reported. \n
-    This method takes about 50s for 1000 geometries. \n
+    """Returns a set of point clouds sampled on the geometries. Each point cloud has its points filtered to not lie wihtin or collide with any of the reference geometries. As such, this method returns the **visible** parts of a set of sampled point clouds. \n
+    
+    For every point cloud, the percentage of visibility is also reported. This method takes about 50s for 1000 geometries. \n
     \n
-    E.g. The figure shows the points of the visible point cloud that were rejected due to their proximity to the other mesh geometries.\n
+    E.g. The figure shows the points of the visible point cloud that were rejected due to their proximity to the other mesh geometries.
 
     .. image:: ../../../docs/pics/invisible_points.PNG
 
@@ -1276,15 +1279,13 @@ def determine_observable_point_cloud(pointcloud:o3d.geometry.PointCloud, resolut
 #     return pcdCropped, percentages
 
 def determine_percentage_of_coverage(sources: List[o3d.geometry.TriangleMesh], reference:o3d.geometry.PointCloud,threshold:float=0.1)-> np.array:
-    """Returns the Percentage-of-Coverage (PoC) of every source geometry when compared to a reference geometry. \n
-    The PoC is defined as the ratio of points on the boundary surface of the source that lie within a Euclidean distance threshold hold of the reference geometry. \n
-    sampled point cloud on the boundary surface of the sources with a resolution of e.g. 0.1m \n
+    """Returns the Percentage-of-Coverage (PoC) of every source geometry when compared to a reference geometry. The PoC is defined as the ratio of points on the boundary surface of the source that lie within a Euclidean distance threshold hold of the reference geometry. sampled point cloud on the boundary surface of the sources with a resolution of e.g. 0.1m. \n
 
-    $$ P_{i'}=\{ p|\forall p \in P_i : p_i \cap N\backslash  n_i \} $$
-    \n
-    $$ c_i = \frac{|P_{i'}|}{|P_i|}$$
-    \n
-    E.g. a mesh of a beam of which half the surface lies within 0.1m of a point cloud will have a PoC of 0.5
+    .. math::
+        P_{i'}=\{ p|\forall p \in P_i : p_i \cap N\backslash  n_i \} 
+        c_i = \frac{|P_{i'}|}{|P_i|}
+    
+    E.g. a mesh of a beam of which half the surface lies within 0.1m of a point cloud will have a PoC of 0.5.
     
     Args:
         1. sources (o3d.geometry.TriangleMesh/PointCloud): geometries to determine the PoC for. \n
@@ -1315,15 +1316,14 @@ def determine_percentage_of_coverage(sources: List[o3d.geometry.TriangleMesh], r
             if 'PointCloud' in str(type(source)) :
                 sourcePCD=source.voxel_down_sample(threshold)
                 indentityArray=np.vstack((indentityArray,np.full((len(sourcePCD.points), 1), i)))
-                sourcePCDs.append(sourcePCD)
             elif 'TriangleMesh' in str(type(source)):
                 area=source.get_surface_area()
                 count=int(area/(threshold*threshold))
                 sourcePCD=source.sample_points_uniformly(number_of_points=count)
                 indentityArray=np.vstack((indentityArray,np.full((len(sourcePCD.points), 1), i)))
-                sourcePCDs.append(sourcePCD)
-            else:
-                raise ValueError('sources must be o3d.geometry (PointCloud or TriangleMesh)')
+            sourcePCDs.append(sourcePCD)
+        else:
+            sourcePCDs.append(None)
 
     indentityArray=indentityArray.flatten()
     indentityArray=np.delete(indentityArray,0)
@@ -1346,7 +1346,7 @@ def determine_percentage_of_coverage(sources: List[o3d.geometry.TriangleMesh], r
     return percentages
 
 def crop_geometry_by_distance(source: o3d.geometry, cutters, threshold : float =0.10) -> o3d.geometry.PointCloud:
-    """"Returns the portion of a pointcloud that lies within a range of another mesh/point cloud.\n
+    """Returns the portion of a pointcloud that lies within a range of another mesh/point cloud.\n
     
     .. image:: ../../../docs/pics/crop_by_distance2.PNG
 
@@ -1406,7 +1406,7 @@ def crop_geometry_by_distance(source: o3d.geometry, cutters, threshold : float =
 #### GEOMETRY PROPERTIES
 
 def get_box_inliers(sourceBox:o3d.geometry.OrientedBoundingBox, testBoxes: List[o3d.geometry.OrientedBoundingBox],t_d:float=0.5)->List[int]:
-    """"Return the indices of the testBoxes of which the bounding points lie within the sourceBox.\n
+    """Return the indices of the testBoxes of which the bounding points lie within the sourceBox.\n
 
     .. image:: ../../../docs/pics/get_box_inliers1.PNG
 
@@ -1431,8 +1431,7 @@ def get_box_inliers(sourceBox:o3d.geometry.OrientedBoundingBox, testBoxes: List[
     return list
 
 def get_mesh_inliers(sources:List[o3d.geometry.TriangleMesh], reference:o3d.geometry.TriangleMesh) -> List[int]:
-    """Returns the indices of the geometries that lie within a reference geometry.\n
-       The watertightness of both source and reference geometries is determined after which the occupancy is computed for a numer of sampled points in the source geometries. \n
+    """Returns the indices of the geometries that lie within a reference geometry. The watertightness of both source and reference geometries is determined after which the occupancy is computed for a numer of sampled points in the source geometries. \n
 
     .. image:: ../../../docs/pics/selection_BB_mesh5.PNG
     
@@ -1493,7 +1492,7 @@ def get_mesh_inliers(sources:List[o3d.geometry.TriangleMesh], reference:o3d.geom
     return ind
 
 def get_box_intersections(sourceBox:o3d.geometry.OrientedBoundingBox, testBoxes: List[o3d.geometry.OrientedBoundingBox])->List[int]:
-    """" Return indices of testBoxes of which the geometry intersects with the sourceBox.\n
+    """Return indices of testBoxes of which the geometry intersects with the sourceBox.\n
     2 oriented bounding boxes (A,B) overlap if the projection from B in the coordinate system of A on all the axes overlap. \n
     The projection of B on the oriented axes of A is simply the coordinate range for that axis.\n
 
@@ -1718,12 +1717,12 @@ def get_mesh_collisions_open3d(sourceMesh: o3d.geometry.TriangleMesh, meshes: Li
         return False
 
 def crop_geometry_by_raycasting(source:o3d.geometry.TriangleMesh, cutter: o3d.geometry.TriangleMesh, inside : Boolean = True,strict : Boolean = True ) -> o3d.geometry.TriangleMesh:
-    """"Select portion of a mesh that lies within a mesh shape (if not closed, convexhull is called).\n
+    """Select portion of a mesh that lies within a mesh shape (if not closed, convexhull is called).\n
     
-    inside=True\n
+    inside=True
     .. image:: ../../../docs/pics/crop_by_ray_casting1.PNG
 
-    inside=False \n
+    inside=False 
     .. image:: ../../../docs/pics/crop_by_ray_casting2.PNG
 
     Args:
