@@ -1,25 +1,24 @@
+import copy
+import math
+import os
+import shutil
+import time
 import unittest
-from context import geomapi
-from geomapi.nodes import *
+from multiprocessing.sharedctypes import Value
+
+import cv2
 import geomapi.utils as ut
 import geomapi.utils.geometryutils as gt
-
-
-from multiprocessing.sharedctypes import Value
-import open3d as o3d
 import ifcopenshell
-from ifcopenshell.util.selector import Selector
-import os
-import time
-import shutil
 import numpy as np
-import cv2
-import pye57
-import copy
-import rdflib
-from rdflib import RDFS, Graph, URIRef, Literal, RDF
-import math
+import open3d as o3d
 import PIL
+import pye57
+import rdflib
+from geomapi.nodes import *
+from ifcopenshell.util.selector import Selector
+from rdflib import RDF, RDFS, Graph, Literal, URIRef
+
 
 class TestNode(unittest.TestCase):
 
@@ -431,4 +430,4 @@ class TestNode(unittest.TestCase):
                 break
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
