@@ -1,25 +1,25 @@
-from re import S
-import unittest
-from context import geomapi
-from geomapi.nodes import *
-import geomapi.utils as ut
-
-from multiprocessing.sharedctypes import Value
-import open3d as o3d
-import ifcopenshell
-from ifcopenshell.util.selector import Selector
-import os
-import time
-import shutil
-import numpy as np
-import cv2
-import pye57
 import copy
-import rdflib
-from rdflib import RDFS, Graph, URIRef, Literal, RDF
 import datetime
 import math
+import os
+import shutil
+import time
+import unittest
+from multiprocessing.sharedctypes import Value
+from re import S
+
+import cv2
+import geomapi.utils as ut
+import ifcopenshell
+import numpy as np
+import open3d as o3d
 import PIL
+import pye57
+import rdflib
+from geomapi.nodes import *
+from ifcopenshell.util.selector import Selector
+from rdflib import RDF, RDFS, Graph, Literal, URIRef
+
 
 class TestNode(unittest.TestCase):
 
@@ -416,4 +416,4 @@ class TestNode(unittest.TestCase):
         self.assertEqual(node.subject.toPython(),testnode.subject.toPython())
     
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
