@@ -1,24 +1,23 @@
-import unittest
-from context import geomapi
-from geomapi.nodes import *
-import geomapi.utils as ut
-
-from multiprocessing.sharedctypes import Value
-import open3d as o3d
-import ifcopenshell
-from ifcopenshell.util.selector import Selector
-import os
-import time
-import shutil
-import numpy as np
-import cv2
-import pye57
 import copy
-import rdflib
-from rdflib import RDFS, Graph, URIRef, Literal, RDF
 import math
-import PIL
+import os
+import shutil
+import time
+import unittest
+from multiprocessing.sharedctypes import Value
+
+import cv2
+import geomapi.utils as ut
 import geomapi.utils.geometryutils as gt
+import ifcopenshell
+import numpy as np
+import open3d as o3d
+import PIL
+import pye57
+import rdflib
+from geomapi.nodes import *
+from ifcopenshell.util.selector import Selector
+from rdflib import RDF, RDFS, Graph, Literal, URIRef
 
 
 class TestNode(unittest.TestCase):
@@ -305,4 +304,4 @@ class TestNode(unittest.TestCase):
         self.assertIsNotNone(node.pointCount)
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
