@@ -1,26 +1,26 @@
-from datetime import datetime
+import copy
+import math
+import os
+import shutil
+import time
 import unittest
-from context import geomapi
+from datetime import datetime
+from multiprocessing.sharedctypes import Value
+
+import cv2
+import geomapi.utils as ut
+import ifcopenshell
+import numpy as np
+import open3d as o3d
+import PIL
+import pye57
 from geomapi.nodes.bimnode import BIMNode
 from geomapi.nodes.imagenode import ImageNode
 from geomapi.nodes.meshnode import MeshNode
 from geomapi.nodes.orthonode import OrthoNode
 from geomapi.nodes.pointcloudnode import PointCloudNode
-import geomapi.utils as ut
-from multiprocessing.sharedctypes import Value
-import open3d as o3d
-import ifcopenshell
 from ifcopenshell.util.selector import Selector
-import os
-import time
-import shutil
-import numpy as np
-import cv2
-import pye57
-import copy
-from rdflib import RDF, Graph, URIRef, Literal, RDFS,XSD
-import math
-import PIL
+from rdflib import RDF, RDFS, XSD, Graph, Literal, URIRef
 
 
 class TestUtils(unittest.TestCase):
@@ -695,4 +695,4 @@ class TestUtils(unittest.TestCase):
         self.assertIsNone(test)
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
